==> blanco.plugin.service_0.1.1-src.zip: blancoServicePlugin/blanco/main/blanco/plugin/service/wizards/AbstractBlancoServiceWizardPage.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.service.wizards;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.service.BlancoServicePluginConstants;

/**
 */
public abstract class AbstractBlancoServiceWizardPage extends WizardPage {
    /**
     */
    private Label labelMessage1;

    /**
     */
    private Label labelMessage2;

    /**
     */
    private ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoServiceWizardPage(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoService vOC pxEBU[h");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoService Wizardւ悤I");
        new Label(container, SWT.NONE).setText("̃EBU[hblancoServicevOCp\ɂȂ܂ł̎菇`܂B");
        new Label(container, SWT.NONE).setText("");
        new Label(container, SWT.NONE).setText("̃EBU[h̎傽ړÍAݒt@C(" + BlancoServicePluginConstants.TARGET_FILENAME + ")vWFNg̃[gtH_ɍ쐬邱ƂłB");
        new Label(container, SWT.NONE).setText("ݒt@C(" + BlancoServicePluginConstants.TARGET_FILENAME + ")Ɋւ󋵂͉L̂悤ɂȂĂ܂B");

        labelMessage1 = new Label(container, SWT.NONE);
        labelMessage1.setText("  1.vWFNg̃[gtH_ " + BlancoServicePluginConstants.TARGET_FILENAME + "t@CVKɍ쐬܂B");
        labelMessage2 = new Label(container, SWT.NONE);
        labelMessage2.setText("  2.EBU[h(Finish)sƂɂVK" + BlancoServicePluginConstants.TARGET_FILENAME + "t@C쐬ĕҏWsƂł܂B");

        setControl(container);

        IProject proj = BlancoServiceWizard.getProject(selection);
        if (proj == null) {
            setErrorMessage("vWFNgIł");
            setPageComplete(false);
            labelMessage1.setText("  1.vWFNgIĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoServicePluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        if (proj.isOpen() == false) {
            setPageComplete(false);
            setErrorMessage("JĂvWFNgIĂAēxEBU[hsĂB");
            labelMessage1.setText("  1.IꂽvWFNg͊JĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoServicePluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        IFile file = proj.getFile(BlancoServicePluginConstants.TARGET_FILENAME);
        if (file.exists()) {
            labelMessage1.setText("  1.ɃvWFNg̃[g " + BlancoServicePluginConstants.TARGET_FILENAME + "t@C݂Ă܂B");
            labelMessage2.setText("  2.EBU[h(Finish)sƂɂ" + BlancoServicePluginConstants.TARGET_FILENAME + "t@C̕ҏWsƂł܂B");
        }
    }
}

==> blanco.plugin.service_0.1.2-src.zip: blancoServicePlugin/blanco/main/blanco/plugin/service/wizards/AbstractBlancoServiceWizardPage.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.service.wizards;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.service.BlancoServicePluginConstants;

/**
 */
public abstract class AbstractBlancoServiceWizardPage extends WizardPage {
    /**
     */
    private Label labelMessage1;

    /**
     */
    private Label labelMessage2;

    /**
     */
    protected ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoServiceWizardPage(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoService vOC pxEBU[h");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoService Wizardւ悤I");
        new Label(container, SWT.NONE).setText("̃EBU[hblancoServicevOCp\ɂȂ܂ł̎菇`܂B");
        new Label(container, SWT.NONE).setText("");
        new Label(container, SWT.NONE).setText("̃EBU[h̎傽ړÍAݒt@C(" + BlancoServicePluginConstants.TARGET_FILENAME + ")vWFNg̃[gtH_ɍ쐬邱ƂłB");
        new Label(container, SWT.NONE).setText("ݒt@C(" + BlancoServicePluginConstants.TARGET_FILENAME + ")Ɋւ󋵂͉L̂悤ɂȂĂ܂B");

        labelMessage1 = new Label(container, SWT.NONE);
        labelMessage1.setText("  1.vWFNg̃[gtH_ " + BlancoServicePluginConstants.TARGET_FILENAME + "t@CVKɍ쐬܂B");
        labelMessage2 = new Label(container, SWT.NONE);
        labelMessage2.setText("  2.EBU[h(Finish)sƂɂVK" + BlancoServicePluginConstants.TARGET_FILENAME + "t@C쐬ĕҏWsƂł܂B");

        setControl(container);

        IProject proj = BlancoServiceWizard.getProject(selection);
        if (proj == null) {
            setErrorMessage("vWFNgIł");
            setPageComplete(false);
            labelMessage1.setText("  1.vWFNgIĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoServicePluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        if (proj.isOpen() == false) {
            setPageComplete(false);
            setErrorMessage("JĂvWFNgIĂAēxEBU[hsĂB");
            labelMessage1.setText("  1.IꂽvWFNg͊JĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoServicePluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        IFile file = proj.getFile(BlancoServicePluginConstants.TARGET_FILENAME);
        if (file.exists()) {
            labelMessage1.setText("  1.ɃvWFNg̃[g " + BlancoServicePluginConstants.TARGET_FILENAME + "t@C݂Ă܂B");
            labelMessage2.setText("  2.EBU[h(Finish)sƂɂ" + BlancoServicePluginConstants.TARGET_FILENAME + "t@C̕ҏWsƂł܂B");
        }
    }
}
